[Libreoffice-commits] core.git: desktop/source embeddedobj/test filter/source fpicker/source framework/qa framework/source odk/examples offapi/com sal/qa sfx2/source

Julien Nabet serval2412 at yahoo.fr
Thu Feb 6 12:23:25 PST 2014


 desktop/source/app/app.cxx                                                                   |    2 -
 embeddedobj/test/Container1/NativeView.java                                                  |    2 -
 filter/source/config/cache/filtercache.cxx                                                   |    2 -
 fpicker/source/win32/filepicker/FileOpenDlg.hxx                                              |    2 -
 framework/qa/complex/framework/autosave/Protocol.java                                        |    2 -
 framework/source/accelerators/acceleratorconfiguration.cxx                                   |    4 +--
 framework/source/dispatch/dispatchprovider.cxx                                               |    2 -
 framework/source/dispatch/interceptionhelper.cxx                                             |    2 -
 framework/source/fwe/classes/framelistanalyzer.cxx                                           |    2 -
 framework/source/fwe/helper/titlehelper.cxx                                                  |    4 +--
 framework/source/loadenv/loadenv.cxx                                                         |    2 -
 framework/source/services/autorecovery.cxx                                                   |   12 +++++-----
 framework/source/services/pathsettings.cxx                                                   |    4 +--
 odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java                       |    4 +--
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/NativeView.java                    |    2 -
 odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java |    4 +--
 offapi/com/sun/star/document/ExtendedTypeDetectionFactory.idl                                |    2 -
 offapi/com/sun/star/document/FilterFactory.idl                                               |    2 -
 offapi/com/sun/star/document/TypeDetection.idl                                               |    2 -
 offapi/com/sun/star/frame/ProtocolHandler.idl                                                |    2 -
 sal/qa/libs2test.txt                                                                         |    2 -
 sfx2/source/appl/appopen.cxx                                                                 |    2 -
 sfx2/source/bastyp/fltfnc.cxx                                                                |    2 -
 23 files changed, 33 insertions(+), 33 deletions(-)

New commits:
commit 6f0e7c36e436c66ed267ea446b7d640033bc3742
Author: Julien Nabet <serval2412 at yahoo.fr>
Date:   Thu Feb 6 21:22:42 2014 +0100

    Typo: seam(s) -> seem(s)
    
    Change-Id: I840d120644760b61a39ad88b4095056f0f753bb7

diff --git a/desktop/source/app/app.cxx b/desktop/source/app/app.cxx
index d017984..e74c3dd 100644
--- a/desktop/source/app/app.cxx
+++ b/desktop/source/app/app.cxx
@@ -1286,7 +1286,7 @@ sal_uInt16 Desktop::Exception(sal_uInt16 nError)
     sal_Bool bAllowRecoveryAndSessionManagement = (
                                                     ( !rArgs.IsNoRestore()                    ) && // some use cases of office must work without recovery
                                                     ( !rArgs.IsHeadless()                     ) &&
-                                                    (( nError & EXC_MAJORTYPE ) != EXC_DISPLAY ) && // recovery cant work without UI ... but UI layer seams to be the reason for this crash
+                                                    (( nError & EXC_MAJORTYPE ) != EXC_DISPLAY ) && // recovery cant work without UI ... but UI layer seems to be the reason for this crash
                                                     ( Application::IsInExecute()               )    // crashes during startup and shutdown should be ignored (they indicates a corrupt installation ...)
                                                   );
     if ( bAllowRecoveryAndSessionManagement )
diff --git a/embeddedobj/test/Container1/NativeView.java b/embeddedobj/test/Container1/NativeView.java
index fbb2b8f..70d7457 100644
--- a/embeddedobj/test/Container1/NativeView.java
+++ b/embeddedobj/test/Container1/NativeView.java
@@ -61,7 +61,7 @@ public class NativeView extends java.awt.Canvas
      * ( e.g. get the window handle and necessary system information )
      *
      * Why here?
-     * Because the handle seams to be available for already visible windows
+     * Because the handle seems to be available for already visible windows
      * only. So it's the best place to get it. Special helper method
      * can be called more then ones - but call native code one times only
      * and safe the handle and the system type on our members maHandle/maSystem!
diff --git a/filter/source/config/cache/filtercache.cxx b/filter/source/config/cache/filtercache.cxx
index 442cc3c..0d15033 100644
--- a/filter/source/config/cache/filtercache.cxx
+++ b/filter/source/config/cache/filtercache.cxx
@@ -2208,7 +2208,7 @@ void FilterCache::impl_readOldFormat()
         xCfg = css::uno::Reference< css::container::XNameAccess >(xInt, css::uno::UNO_QUERY_THROW);
     }
     /* corrupt filter addon ? because it's external (optional) code .. we can ignore it. Addon wont work then ...
-       but that seams to be acceptable.
+       but that seems to be acceptable.
        see #139088# for further information
     */
     catch(const css::uno::Exception&)
diff --git a/fpicker/source/win32/filepicker/FileOpenDlg.hxx b/fpicker/source/win32/filepicker/FileOpenDlg.hxx
index 94b0281..ca40576 100644
--- a/fpicker/source/win32/filepicker/FileOpenDlg.hxx
+++ b/fpicker/source/win32/filepicker/FileOpenDlg.hxx
@@ -113,7 +113,7 @@ typedef _LPOPENFILENAMEA _LPOPENFILENAME;
         #define _OPENFILENAME_SIZE_VERSION_400  _OPENFILENAME_SIZE_VERSION_400A
     #endif // !UNICODE
 #else
-    #error _WIN32_WINNT seams not to be valid.
+    #error _WIN32_WINNT seems not to be valid.
 #endif // (_WIN32_WINNT >= 0x0500)
 
 
diff --git a/framework/qa/complex/framework/autosave/Protocol.java b/framework/qa/complex/framework/autosave/Protocol.java
index 295ed18..8c92b09 100644
--- a/framework/qa/complex/framework/autosave/Protocol.java
+++ b/framework/qa/complex/framework/autosave/Protocol.java
@@ -496,7 +496,7 @@ public class Protocol extends JComponent
      * log an unspecified message.
      *
      * Sometimes it's not necessary to set a special type for an message.
-     * The pure message seams to be enough. The type of such "pure messages"
+     * The pure message seems to be enough. The type of such "pure messages"
      * will be set to INFO.
      *
      * @param   sMessage
diff --git a/framework/source/accelerators/acceleratorconfiguration.cxx b/framework/source/accelerators/acceleratorconfiguration.cxx
index b645b3b..d76fea6 100644
--- a/framework/source/accelerators/acceleratorconfiguration.cxx
+++ b/framework/source/accelerators/acceleratorconfiguration.cxx
@@ -142,7 +142,7 @@ void SAL_CALL XMLBasedAcceleratorConfiguration::setKeyEvent(const css::awt::KeyE
         (aKeyEvent.Modifiers == 0)
         )
         throw css::lang::IllegalArgumentException(
-        OUString("Such key event seams not to be supported by any operating system."),
+        OUString("Such key event seems not to be supported by any operating system."),
         static_cast< ::cppu::OWeakObject* >(this),
         0);
 
@@ -689,7 +689,7 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::setKeyEvent(const css::awt::KeyE
         (aKeyEvent.Modifiers == 0)
         )
         throw css::lang::IllegalArgumentException(
-                OUString("Such key event seams not to be supported by any operating system."),
+                OUString("Such key event seems not to be supported by any operating system."),
                 static_cast< ::cppu::OWeakObject* >(this),
                 0);
 
diff --git a/framework/source/dispatch/dispatchprovider.cxx b/framework/source/dispatch/dispatchprovider.cxx
index 7b5c746..8a6327d 100644
--- a/framework/source/dispatch/dispatchprovider.cxx
+++ b/framework/source/dispatch/dispatchprovider.cxx
@@ -354,7 +354,7 @@ css::uno::Reference< css::frame::XDispatch > DispatchProvider::implts_queryFrame
         {
             css::uno::Reference< css::frame::XDispatchProvider > xParent( xFrame->getCreator(), css::uno::UNO_QUERY );
             // Normaly if isTop() returned sal_False ... the parent frame MUST(!) exist ...
-            // But it seams to be better to check that here to prevent us against an access violation.
+            // But it seems to be better to check that here to prevent us against an access violation.
             if (xParent.is())
                 xDispatcher = xParent->queryDispatch(aURL, SPECIALTARGET_TOP, 0);
         }
diff --git a/framework/source/dispatch/interceptionhelper.cxx b/framework/source/dispatch/interceptionhelper.cxx
index c782ec6..37ff33e 100644
--- a/framework/source/dispatch/interceptionhelper.cxx
+++ b/framework/source/dispatch/interceptionhelper.cxx
@@ -274,7 +274,7 @@ void SAL_CALL InterceptionHelper::disposing(const css::lang::EventObject& aEvent
     // SAFE ->
     aReadLock.lock();
     if (!m_lInterceptionRegs.empty() )
-        OSL_FAIL("There are some pending interceptor objects, which seams to be registered during (!) the destruction of a frame.");
+        OSL_FAIL("There are some pending interceptor objects, which seems to be registered during (!) the destruction of a frame.");
     aReadLock.unlock();
     // <- SAFE
     #endif // ODL_DEBUG_LEVEL>0
diff --git a/framework/source/fwe/classes/framelistanalyzer.cxx b/framework/source/fwe/classes/framelistanalyzer.cxx
index 04124b0..aae1aa4 100644
--- a/framework/source/fwe/classes/framelistanalyzer.cxx
+++ b/framework/source/fwe/classes/framelistanalyzer.cxx
@@ -256,7 +256,7 @@ void FrameListAnalyzer::impl_analyze()
     }
     catch (const css::lang::IndexOutOfBoundsException&)
     {
-        // stop copying if index seams to be wrong.
+        // stop copying if index seems to be wrong.
         // This interface can't really guarantee its count for multithreaded
         // environments. So it can occur!
     }
diff --git a/framework/source/fwe/helper/titlehelper.cxx b/framework/source/fwe/helper/titlehelper.cxx
index 0e3a97b..e19a679 100644
--- a/framework/source/fwe/helper/titlehelper.cxx
+++ b/framework/source/fwe/helper/titlehelper.cxx
@@ -103,11 +103,11 @@ OUString SAL_CALL TitleHelper::getTitle()
         if (m_bExternalTitle)
             return m_sTitle;
 
-        // Title seams to be up-to-date. Return it directly.
+        // Title seems to be up-to-date. Return it directly.
         if (!m_sTitle.isEmpty())
             return m_sTitle;
 
-        // Title seams to be unused till now ... do bootstraping
+        // Title seems to be unused till now ... do bootstraping
         impl_updateTitle (true);
 
         return m_sTitle;
diff --git a/framework/source/loadenv/loadenv.cxx b/framework/source/loadenv/loadenv.cxx
index c43748c..7aa849a 100644
--- a/framework/source/loadenv/loadenv.cxx
+++ b/framework/source/loadenv/loadenv.cxx
@@ -1549,7 +1549,7 @@ css::uno::Reference< css::frame::XFrame > LoadEnv::impl_searchRecycleTarget()
     if (eOldApp != eNewApp)
         return css::uno::Reference< css::frame::XFrame >();
 
-    // OK this task seams to be usable for recycling
+    // OK this task seems to be usable for recycling
     // But we should mark it as such - means set an action lock.
     // Otherwise it would be used more then ones or will be destroyed
     // by a close() or terminate() request.
diff --git a/framework/source/services/pathsettings.cxx b/framework/source/services/pathsettings.cxx
index dad1a43..f551f29 100644
--- a/framework/source/services/pathsettings.cxx
+++ b/framework/source/services/pathsettings.cxx
@@ -420,7 +420,7 @@ private:
           PathSettings::PathInfo* impl_getPathAccess     (sal_Int32 nHandle);
     const PathSettings::PathInfo* impl_getPathAccessConst(sal_Int32 nHandle) const;
 
-    /** it checks, if the given path value seams to be a valid URL or system path. */
+    /** it checks, if the given path value seems to be a valid URL or system path. */
     sal_Bool impl_isValidPath(const OUString& sPath) const;
     sal_Bool impl_isValidPath(const OUStringList&    lPath) const;
 
@@ -1438,7 +1438,7 @@ css::uno::Reference< css::util::XStringSubstitution > PathSettings::fa_getSubsti
         // create the needed substitution service.
         // We must replace all used variables inside readed path values.
         // In case we can't do so ... the whole office can't work really.
-        // That's why it seams to be OK to throw a RuntimeException then.
+        // That's why it seems to be OK to throw a RuntimeException then.
         xSubst = css::util::PathSubstitution::create(m_xContext);
 
         { // SAFE ->
diff --git a/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java b/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java
index 081502b..d0ffaaf 100644
--- a/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java
+++ b/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java
@@ -55,7 +55,7 @@ public class AsyncJob extends    WeakBase implements XServiceInfo, XAsyncJob
     public static final java.lang.String[] SERVICENAMES = {"com.sun.star.task.AsyncJob"};
 
     /** the const uno implementation name.
-     *  It must be an unique value! The best naming schema seams to use
+     *  It must be an unique value! The best naming schema seems to use
      *  a registered domain in reverse order ...
      */
     public static final java.lang.String IMPLEMENTATIONNAME = "com.sun.star.comp.framework.java.services.AsyncJob";
@@ -86,7 +86,7 @@ public class AsyncJob extends    WeakBase implements XServiceInfo, XAsyncJob
      *          callback to the executor of this job, which control our life time
      *
      *  @throws com.sun.star.lang.IllegalArgumentException
-     *          if given argument list seams to be wrong
+     *          if given argument list seems to be wrong
      */
     public synchronized void executeAsync(com.sun.star.beans.NamedValue[] lArgs    ,
                                           com.sun.star.task.XJobListener  xListener)
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/NativeView.java b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/NativeView.java
index d374af0..270baf2 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/NativeView.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/NativeView.java
@@ -74,7 +74,7 @@ public class NativeView extends java.awt.Canvas
      * (e.g. get the window handle and necessary system information)
      *
      * Why here?
-     * Because the handle seams to be available for already visible windows
+     * Because the handle seems to be available for already visible windows
      * only. So it's the best place to get it. Special helper method
      * can be called more then ones - but call native code one times only
      * and safe the handle and the system type on our members maHandle/maSystem!
diff --git a/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java b/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java
index 7dfce47..1dc9328 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/AsciiFilter/AsciiReplaceFilter.java
@@ -248,7 +248,7 @@ public class AsciiReplaceFilter
         *          the document model for importing
         *
         * @throw IllegalArgumentException
-        *          if given document isn't the right one or seams to be corrupt
+        *          if given document isn't the right one or seems to be corrupt
         */
         public void setTargetDocument( com.sun.star.lang.XComponent xDocument ) throws com.sun.star.lang.IllegalArgumentException
         {
@@ -284,7 +284,7 @@ public class AsciiReplaceFilter
         *          the document model for exporting
         *
         * @throw IllegalArgumentException
-        *          if given document isn't the right one or seams to be corrupt
+        *          if given document isn't the right one or seems to be corrupt
         */
         public void setSourceDocument( com.sun.star.lang.XComponent xDocument ) throws com.sun.star.lang.IllegalArgumentException
         {
diff --git a/offapi/com/sun/star/document/ExtendedTypeDetectionFactory.idl b/offapi/com/sun/star/document/ExtendedTypeDetectionFactory.idl
index 949f425..4f9b7c6 100644
--- a/offapi/com/sun/star/document/ExtendedTypeDetectionFactory.idl
+++ b/offapi/com/sun/star/document/ExtendedTypeDetectionFactory.idl
@@ -109,7 +109,7 @@ published service ExtendedTypeDetectionFactory
 
         <p>
         Because the complexness of such configuration set can be very high,
-        it seams not very useful to update the underlying configuration layer
+        it seems not very useful to update the underlying configuration layer
         on every container change request immediately. Another strategy can be to
         make all changes (adding/changing/removing of items) and call flush at the end.
         That will validate the whole container and reject inconsistent data sets.
diff --git a/offapi/com/sun/star/document/FilterFactory.idl b/offapi/com/sun/star/document/FilterFactory.idl
index 240ff08..59a17ed 100644
--- a/offapi/com/sun/star/document/FilterFactory.idl
+++ b/offapi/com/sun/star/document/FilterFactory.idl
@@ -206,7 +206,7 @@ published service FilterFactory
 
         <p>
         Because the complexness of such configuration set can be very high,
-        it seams not very useful to update the underlying configuration layer
+        it seems not very useful to update the underlying configuration layer
         on every container change request immediately. Another strategy can be to
         make all changes (adding/changing/removing of items) and call flush at the end.
         That will validate the whole container and reject inconsistent data sets.
diff --git a/offapi/com/sun/star/document/TypeDetection.idl b/offapi/com/sun/star/document/TypeDetection.idl
index 1fd3eac..de5e9c4 100644
--- a/offapi/com/sun/star/document/TypeDetection.idl
+++ b/offapi/com/sun/star/document/TypeDetection.idl
@@ -153,7 +153,7 @@ published service TypeDetection
 
         <p>
         Because the complexness of such configuration set can be very high,
-        it seams not very useful to update the underlying configuration layer
+        it seems not very useful to update the underlying configuration layer
         on every container change request immediately. Another strategy can be to
         make all changes (adding/changing/removing of items) and call flush at the end.
         That will validate the whole container and reject inconsistent data sets.
diff --git a/offapi/com/sun/star/frame/ProtocolHandler.idl b/offapi/com/sun/star/frame/ProtocolHandler.idl
index 59dccd9..ffdaa31 100644
--- a/offapi/com/sun/star/frame/ProtocolHandler.idl
+++ b/offapi/com/sun/star/frame/ProtocolHandler.idl
@@ -66,7 +66,7 @@ published service ProtocolHandler
         </p>
 
         <p>
-        Please note: if this mechanism is used it seams not useful (nor possible) to implement a ProtocolHandler
+        Please note: if this mechanism is used it seems not useful (nor possible) to implement a ProtocolHandler
         as a singleton. Otherwise the implementation can't distinguish between different environments
         and her corresponding dispatch requests.
         </p>
diff --git a/sal/qa/libs2test.txt b/sal/qa/libs2test.txt
index d41bf06..4c2208c 100644
--- a/sal/qa/libs2test.txt
+++ b/sal/qa/libs2test.txt
@@ -89,7 +89,7 @@ rtl/oustringbuffer; rtl_OUStringBuffer2
 rtl/uri       ; rtl_Uri
 rtl/logfile   ; rtl_logfile
 
-# LLA: Due to the fact, that thread testing seams to be little bit error prone, now
+# LLA: Due to the fact, that thread testing seems to be little bit error prone, now
 # check this at the end.
 osl/process   ; osl_Thread
 
diff --git a/sfx2/source/appl/appopen.cxx b/sfx2/source/appl/appopen.cxx
index bf947fb..69d0b37 100644
--- a/sfx2/source/appl/appopen.cxx
+++ b/sfx2/source/appl/appopen.cxx
@@ -771,7 +771,7 @@ void SfxApplication::OpenDocExec_Impl( SfxRequest& rReq )
         rReq.AppendItem( SfxBoolItem( SID_TEMPLATE, false ) );
     }
     // pass URL to OS by using ShellExecuter or open it internal
-    // if it seams to be an own format.
+    // if it seems to be an own format.
     /* Attention!
             There exist two possibilities to open hyperlinks:
             a) using SID_OPENHYPERLINK (new)
diff --git a/sfx2/source/bastyp/fltfnc.cxx b/sfx2/source/bastyp/fltfnc.cxx
index a7a6bf8..7fb213a 100644
--- a/sfx2/source/bastyp/fltfnc.cxx
+++ b/sfx2/source/bastyp/fltfnc.cxx
@@ -1153,7 +1153,7 @@ void SfxFilterContainer::ReadFilters_Impl( sal_Bool bUpdate )
             {
                 // If list of filters already exist ...
                 // ReadExternalFilters must work in update mode.
-                // Best way seams to mark all filters NOT_INSTALLED
+                // Best way seems to mark all filters NOT_INSTALLED
                 // and change it back for all valid filters afterwards.
                 if( !rList.empty() )
                 {


More information about the Libreoffice-commits mailing list
diff --git a/framework/source/services/autorecovery.cxx b/framework/source/services/autorecovery.cxx
index d9b86dc..6ec5d43 100644
--- a/framework/source/services/autorecovery.cxx
+++ b/framework/source/services/autorecovery.cxx
@@ -304,7 +304,7 @@ public:
 
             //-------------------------------
             /** For every user action, which modifies a document (e.g. key input) we get
-                a notification as XModifyListener. That seams to be a "performance issue" .-)
+                a notification as XModifyListener. That seems to be a "performance issue" .-)
                 So we decided to listen for such modify events only for the time in which the document
                 was stored as temp. file and was not modified again by the user.
             */
@@ -1185,8 +1185,8 @@ static const char OPERATION_UPDATE[] = "update";
 static const sal_Int32       MIN_DISCSPACE_DOCSAVE                  =   5; // [MB]
 static const sal_Int32       MIN_DISCSPACE_CONFIGSAVE               =   1; // [MB]
 static const sal_Int32       RETRY_STORE_ON_FULL_DISC_FOREVER       = 300; // not forever ... but often enough .-)
-static const sal_Int32       RETRY_STORE_ON_MIGHT_FULL_DISC_USEFULL =   3; // in case FULL DISC does not seam the real problem
-static const sal_Int32       GIVE_UP_RETRY                          =   1; // in case FULL DISC does not seam the real problem
+static const sal_Int32       RETRY_STORE_ON_MIGHT_FULL_DISC_USEFULL =   3; // in case FULL DISC does not seem the real problem
+static const sal_Int32       GIVE_UP_RETRY                          =   1; // in case FULL DISC does not seem the real problem
 
 #define SAVE_IN_PROGRESS            sal_True
 #define SAVE_FINISHED               sal_False
@@ -2276,7 +2276,7 @@ void AutoRecovery::implts_flushConfigItem(const AutoRecovery::TDocumentInfo& rIn
         }
         catch(const css::uno::Exception&)
         {
             // a) FULL DISC seams to be the problem behind                              => show error and retry it forever (e.g. retry=300)
             // b) unknown problem (may be locking problem)                              => reset RETRY value to more useful value(!) (e.g. retry=3)
             // c) unknown problem (may be locking problem) + 1..2 repeating operations  => throw the original exception to force generation of a stacktrace !
 
@@ -3001,7 +3001,7 @@ void AutoRecovery::implts_prepareSessionShutdown()
                 catch(const css::uno::Exception&)
                 {
                     // At least it's only a try to close these documents before anybody else it does.
                     // So it seams to be possible to ignore any error here .-)
                 }
 
                 rInfo.Document.clear();
@@ -3288,7 +3288,7 @@ void AutoRecovery::implts_saveOneDoc(const OUString&
         {
             bError = sal_True;
 
             // a) FULL DISC seams to be the problem behind                              => show error and retry it forever (e.g. retry=300)
             // b) unknown problem (may be locking problem)                              => reset RETRY value to more useful value(!) (e.g. retry=3)
             // c) unknown problem (may be locking problem) + 1..2 repeating operations  => throw the original exception to force generation of a stacktrace !
 
@@ -2276,7 +2276,7 @@ void AutoRecovery::implts_flushConfigItem(const AutoRecovery::TDocumentInfo& rIn
         catch(const css::uno::Exception&)
         {
-            // a) FULL DISC seams to be the problem behind                              => show error and retry it forever (e.g. retry=300)
+            // a) FULL DISC seems to be the problem behind                              => show error and retry it forever (e.g. retry=300)
             // b) unknown problem (may be locking problem)                              => reset RETRY value to more useful value(!) (e.g. retry=3)
             // c) unknown problem (may be locking problem) + 1..2 repeating operations  => throw the original exception to force generation of a stacktrace !
@@ -3001,7 +3001,7 @@ void AutoRecovery::implts_prepareSessionShutdown()
                 {
                     // At least it's only a try to close these documents before anybody else it does.
-                    // So it seams to be possible to ignore any error here .-)
+                    // So it seems to be possible to ignore any error here .-)
                 }
 
@@ -3288,7 +3288,7 @@ void AutoRecovery::implts_saveOneDoc(const OUString&
             bError = sal_True;
 
-            // a) FULL DISC seams to be the problem behind                              => show error and retry it forever (e.g. retry=300)
+            // a) FULL DISC seems to be the problem behind                              => show error and retry it forever (e.g. retry=300)
             // b) unknown problem (may be locking problem)                              => reset RETRY value to more useful value(!) (e.g. retry=3)
             // c) unknown problem (may be locking problem) + 1..2 repeating operations  => throw the original exception to force generation of a stacktrace !